==> kubernetes-model-flowcontrol-6.3.0-sources.jar: io/fabric8/kubernetes/api/model/flowcontrol/v1beta2/LimitedPriorityLevelConfigurationFluent.java <==
package io.fabric8.kubernetes.api.model.flowcontrol.v1beta2;

import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Integer;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface LimitedPriorityLevelConfigurationFluent<A extends LimitedPriorityLevelConfigurationFluent<A>> extends Fluent<A>{
  public Integer getAssuredConcurrencyShares();
  public A withAssuredConcurrencyShares(Integer assuredConcurrencyShares);
  public Boolean hasAssuredConcurrencyShares();
  
  /**
   * This method has been deprecated, please use method buildLimitResponse instead.
   * @return The buildable object.
   */
  @Deprecated
  public LimitResponse getLimitResponse();
  public LimitResponse buildLimitResponse();
  public A withLimitResponse(LimitResponse limitResponse);
  public Boolean hasLimitResponse();
  public LimitedPriorityLevelConfigurationFluent.LimitResponseNested<A> withNewLimitResponse();
  public LimitedPriorityLevelConfigurationFluent.LimitResponseNested<A> withNewLimitResponseLike(LimitResponse item);
  public LimitedPriorityLevelConfigurationFluent.LimitResponseNested<A> editLimitResponse();
  public LimitedPriorityLevelConfigurationFluent.LimitResponseNested<A> editOrNewLimitResponse();
  public LimitedPriorityLevelConfigurationFluent.LimitResponseNested<A> editOrNewLimitResponseLike(LimitResponse item);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface LimitResponseNested<N> extends Nested<N>,LimitResponseFluent<LimitedPriorityLevelConfigurationFluent.LimitResponseNested<N>>{
    public N and();
    public N endLimitResponse();
    
  }
  
}

==> kubernetes-model-flowcontrol-6.5.1-sources.jar: io/fabric8/kubernetes/api/model/flowcontrol/v1beta2/LimitedPriorityLevelConfigurationFluent.java <==
package io.fabric8.kubernetes.api.model.flowcontrol.v1beta2;

import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Integer;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface LimitedPriorityLevelConfigurationFluent<A extends LimitedPriorityLevelConfigurationFluent<A>> extends Fluent<A>{
  public Integer getAssuredConcurrencyShares();
  public A withAssuredConcurrencyShares(Integer assuredConcurrencyShares);
  public Boolean hasAssuredConcurrencyShares();
  public Integer getBorrowingLimitPercent();
  public A withBorrowingLimitPercent(Integer borrowingLimitPercent);
  public Boolean hasBorrowingLimitPercent();
  public Integer getLendablePercent();
  public A withLendablePercent(Integer lendablePercent);
  public Boolean hasLendablePercent();
  
  /**
   * This method has been deprecated, please use method buildLimitResponse instead.
   * @return The buildable object.
   */
  @Deprecated
  public LimitResponse getLimitResponse();
  public LimitResponse buildLimitResponse();
  public A withLimitResponse(LimitResponse limitResponse);
  public Boolean hasLimitResponse();
  public LimitedPriorityLevelConfigurationFluent.LimitResponseNested<A> withNewLimitResponse();
  public LimitedPriorityLevelConfigurationFluent.LimitResponseNested<A> withNewLimitResponseLike(LimitResponse item);
  public LimitedPriorityLevelConfigurationFluent.LimitResponseNested<A> editLimitResponse();
  public LimitedPriorityLevelConfigurationFluent.LimitResponseNested<A> editOrNewLimitResponse();
  public LimitedPriorityLevelConfigurationFluent.LimitResponseNested<A> editOrNewLimitResponseLike(LimitResponse item);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface LimitResponseNested<N> extends Nested<N>,LimitResponseFluent<LimitedPriorityLevelConfigurationFluent.LimitResponseNested<N>>{
    public N and();
    public N endLimitResponse();
    
  }
  
}
